@@ -2,11 +2,13 @@ from __future__ import absolute_import
 
 # import apis into api package
 from .capture_api import CaptureApi
+from .conversion_details_api import ConversionDetailsApi
 from .credit_api import CreditApi
 from .flex_token_api import FlexTokenApi
 from .instrument_identifier_api import InstrumentIdentifierApi
 from .instrument_identifiers_api import InstrumentIdentifiersApi
 from .key_generation_api import KeyGenerationApi
+from .net_fundings_api import NetFundingsApi
 from .notification_of_changes_api import NotificationOfChangesApi
 from .payment_instruments_api import PaymentInstrumentsApi
 from .payments_api import PaymentsApi
@@ -20,7 +22,6 @@ from .reports_api import ReportsApi
 from .reversal_api import ReversalApi
 from .search_transactions_api import SearchTransactionsApi
 from .secure_file_share_api import SecureFileShareApi
-from .transaction_batch_api import TransactionBatchApi
 from .transaction_batches_api import TransactionBatchesApi
 from .transaction_details_api import TransactionDetailsApi
 from .user_management_api import UserManagementApi
